WTForms-Alchemy
===============

WTForms-Alchemy is a WTForms extension toolkit for easier creation of model
based forms. Strongly influenced by Django ModelForm.




.. toctree::
   :maxdepth: 2

   introduction
   column_conversion
   types
   customization
   validators
   configuration
   relationships
   advanced
   api
   license





.. _`SQLAlchemy-Utils ChoiceType`: https://sqlalchemy-utils.readthedocs.io/en/latest/#choicetype
.. _`SQLAlchemy-Defaults`: https://sqlalchemy-defaults.readthedocs.io/en/latest/
.. _`Flask-WTF`: https://flask-wtf.readthedocs.io/en/latest/

